/*****************************************************************************
 * Copyright (c) 2020 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   CEA LIST - Initial API and implementation
 *   
 *****************************************************************************/

package org.eclipse.papyrus.cdo.internal.core.resource;

import org.eclipse.core.runtime.Assert;
import org.eclipse.core.runtime.IPath;
import org.eclipse.emf.common.util.URI;
import org.eclipse.papyrus.infra.internationalization.modelresource.AbstractInternationalizationPreferenceModelProvider;
import org.eclipse.papyrus.infra.internationalization.modelresource.InternationalizationPreferenceModel;


public class CDOInternationalizationPreferenceModelProvider extends AbstractInternationalizationPreferenceModelProvider {

	public static final String CDO_LOCAL_PREFERENCEMODEL_URI_PREFIX = "/cdo.checkout/";//$NON-NLS-1$

	public CDOInternationalizationPreferenceModelProvider() {
		super();
	}

	/**
	 * This method is computing the URI for the case when the location of the internationalization
	 * preference information is located in a local "hidden" directory. (~/.metadata/etc...")
	 * In the case where the Papyrus model is an CDO resource, we provide a new mechanism to compute a local URI.
	 * 
	 * @see org.eclipse.papyrus.infra.internationalization.modelresource.IInternationalizationPreferenceModelProvider#getInternationalizationPreferenceModelURI(org.eclipse.emf.common.util.URI)
	 *
	 * @param userModelURI
	 * @return
	 */
	@Override
	public URI getInternationalizationPreferenceModelURI(URI userModelURI) {
		Assert.isNotNull(userModelURI);
		final IPath internationalizationWorkspaceLocation = org.eclipse.papyrus.infra.internationalization.Activator.getDefault().getStateLocation();
		final URI modelURI = userModelURI.trimFileExtension();
		URI internationalizationModelURI = null;
		internationalizationModelURI = URI.createFileURI(internationalizationWorkspaceLocation.append(CDO_LOCAL_PREFERENCEMODEL_URI_PREFIX + modelURI.devicePath()).toPortableString());
		internationalizationModelURI = internationalizationModelURI.appendFileExtension(InternationalizationPreferenceModel.INTERNATIONALIZATION_PREFERENCE_FILE_EXTENSION);

		return internationalizationModelURI;
	}



}
